@@ -1,6 +1,6 @@
 package Template::Perlish;
 
-$VERSION = '1.20';
+$VERSION = '1.21';
 
 use 5.008_000;
 use warnings;
@@ -145,12 +145,6 @@ sub _compile_code_text {
 sub _compile_sub {
    my ($self, $outcome) = @_;
 
-   {
-      open my $fh, '>:raw', '/tmp/generated.pl'
-         or die "open(): $OS_ERROR";
-      print {$fh} $outcome->{code_text};
-   }
-
    my @warnings;
    {
       my $utf8 = $self->{utf8} ? 1 : 0;
@@ -281,7 +275,7 @@ Template::Perlish - Yet Another Templating system for Perl
 
 =head1 VERSION
 
-This document describes Template::Perlish version 1.20. Most likely, this
+This document describes Template::Perlish version 1.21. Most likely, this
 version number here is outdate, and you should peek the source.
 
 
